@@ -13,10 +13,10 @@ if [ "${build_system}" = "cmake" ]; then
     # Use the libs installed with pacman instead of those in
     # https://gitlab.com/graphviz/graphviz-windows-dependencies.
     export CMAKE_OPTIONS="${CMAKE_OPTIONS:-} -Duse_win_pre_inst_libs=OFF"
-    export CMAKE_OPTIONS="$CMAKE_OPTIONS -Denable_ltdl=ON"
-    export CMAKE_OPTIONS="$CMAKE_OPTIONS -Dwith_expat=ON"
-    export CMAKE_OPTIONS="$CMAKE_OPTIONS -Dwith_gvedit=ON"
-    export CMAKE_OPTIONS="$CMAKE_OPTIONS -Dwith_zlib=ON"
+    export CMAKE_OPTIONS="$CMAKE_OPTIONS -DENABLE_LTDL=ON"
+    export CMAKE_OPTIONS="$CMAKE_OPTIONS -DWITH_EXPAT=ON"
+    export CMAKE_OPTIONS="$CMAKE_OPTIONS -DWITH_GVEDIT=ON"
+    export CMAKE_OPTIONS="$CMAKE_OPTIONS -DWITH_ZLIB=ON"
 fi
 
 ci/build.sh
