@@ -8,7 +8,6 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
 #include <sparse/general.h>
 #include <sparse/SparseMatrix.h>
 #include <sparse/QuadTree.h>
@@ -18,6 +17,7 @@
 #include <sparse/color_palette.h>
 #include <stdbool.h>
 #include <string.h>
+#include <util/alloc.h>
 
 static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
                                              bool weightedQ, SparseMatrix A,
@@ -176,23 +176,9 @@ static void node_distinct_coloring_internal(int scheme, QuadTree qt,
  
 }
 
-int node_distinct_coloring(char *color_scheme, int *lightness,
+int node_distinct_coloring(const char *color_scheme, int *lightness,
                            bool weightedQ, SparseMatrix A0, double accuracy,
                            int seed, int *cdim0, double **colors) {
-  /* 
-     for a graph A, get a distinctive color of its nodes so that the color distance among all neighboring nodes are maximized. Here
-     color distance on a node is defined as the minimum of color differences between a node and its neighbors (or the minimum of weighted color differences if weightedQ = true,
-     where weights are stored as entries of A0.
-     accuracy is the threshold given so that when finding the coloring for each node, the optimal is
-     with in "accuracy" of the true global optimal. 
-     color_scheme: rgb, gray, lab, or one of the color palettes in color_palettes.h, or a list of hex rgb colors separaterd by comma like "#ff0000,#00ff00"
-     lightness: of the form 0,70, specifying the range of lightness of LAB color. Ignored if scheme is not COLOR_LAB.
-     A: the graph of n nodes
-     accuracy: how accurate to find the optimal
-     seed: random_seed. If negative, consider -seed as the number of random start iterations
-     cdim: dimension of the color space
-     color: On input an array of size n*cdim, if NULL, will be allocated. On exit the final color assignment for node i is [cdim*i,cdim*(i+1)), in RGB (between 0 to 1)
-  */ 
   SparseMatrix B, A = A0;
   int ncomps, *comps = NULL;
   int nn, n;
@@ -201,9 +187,7 @@ int node_distinct_coloring(char *color_scheme, int *lightness,
   int cdim;
   int scheme = COLOR_LAB;
   int maxcolors = 10000, max_qtree_level = 10, r, g, b;
-  char *color_list = NULL;
-
-  color_list = color_palettes_get(color_scheme);
+  const char *color_list = color_palettes_get(color_scheme);
   if (color_list) color_scheme = color_list;
 
   cdim = *cdim0 = 3;
@@ -261,6 +245,7 @@ int node_distinct_coloring(char *color_scheme, int *lightness,
     }
     SparseMatrix_delete(B);
   }
+  free(comps_ptr);
   free(ctmp);
   QuadTree_delete(qt);
 
