@@ -22,13 +22,12 @@ extern "C" {
 #if !defined(_EXGRAM_H) && ( defined(MINTOKEN) || defined(YYTOKENTYPE) )
 #define _EXGRAM_H
 
-#include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <expr/exlib.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+#include <util/agxbuf.h>
 
 #define ex_lex()		extoken_fn(expr.program)
 
@@ -866,9 +865,7 @@ expop(Expr_t* p)
  * clear global state of stale pointers
  */
 
-void exinit(void) {
-	memset (&expr, 0, sizeof(Exstate_t));
-}
+void exinit(void) { expr = (Exstate_t){0}; }
 
 int excomp(Expr_t *p, const char *name, int line, FILE *fp, char *prefix) {
 	int	eof;
