@@ -9,22 +9,21 @@
  *************************************************************************/
 
 #include <assert.h>
-#include <cgraph/alloc.h>
 #include <glcomp/glcomptexture.h>
 #include <glcomp/glpangofont.h>
 #include <stddef.h>
 #include <stdbool.h>
+#include <util/alloc.h>
+#include <util/streq.h>
 
 static glCompTex *glCompSetAddNewTexture(glCompSet *s, int width, int height,
-                                         unsigned char *data, bool is2D) {
-    int Er, offset, ind;
+                                         const unsigned char *data, bool is2D) {
+    int offset, ind;
     unsigned char *tarData;
-    unsigned char *srcData;
 
     if (!data)
 	return NULL;
 
-    Er = 0;
     glCompTex *t = gv_alloc(sizeof(glCompTex));
     if (!is2D) {		/*use opengl texture */
 	glEnable(GL_TEXTURE_2D);
@@ -35,7 +34,8 @@ static glCompTex *glCompSetAddNewTexture(glCompSet *s, int width, int height,
 	if (glGetError() != GL_NO_ERROR) {		/*for some opengl based error , texture couldnt be created */
 	    /* drain the OpenGL error queue */
 	    while (glGetError() != GL_NO_ERROR);
-	    Er = 1;
+	    free(t);
+	    return NULL;
 	} else {
 	    glBindTexture(GL_TEXTURE_2D, t->id);
 	    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
@@ -49,7 +49,7 @@ static glCompTex *glCompSetAddNewTexture(glCompSet *s, int width, int height,
 	    glDisable(GL_TEXTURE_2D);
 	}
     }
-    if (is2D && !Er) {
+    if (is2D) {
 	assert(width >= 0);
 	assert(height >= 0);
 	t->data = gv_calloc(4 * (unsigned)width * (unsigned)height,
@@ -57,20 +57,15 @@ static glCompTex *glCompSetAddNewTexture(glCompSet *s, int width, int height,
 	offset = 4;		//RGBA  mod,TO DO implement other modes 
 	/*data upside down because of pango gl coord system */
 	for (ind = 0; ind < height; ind++) {
-	    srcData = data + (height - 1 - ind) * offset * width;
+	    const unsigned char *srcData = data + (height - 1 - ind) * offset * width;
 	    tarData = t->data + ind * offset * width;
 	    memcpy(tarData, srcData, 4 * (unsigned)width);
 	}
     }
 
-    if (Er) {
-	free(data);
-	free(t);
-	return NULL;
-    }
     t->userCount = 1;
-    t->width = (float)width;
-    t->height = (float)height;
+    t->width = width;
+    t->height = height;
     if(s)
     {
 	s->textures =
@@ -84,7 +79,7 @@ static glCompTex *glCompSetAddNewTexture(glCompSet *s, int width, int height,
 }
 
 glCompTex *glCompSetAddNewTexImage(glCompSet *s, int width, int height,
-                                   unsigned char *data, bool is2D) {
+                                   const unsigned char *data, bool is2D) {
 
     glCompTex *t;
     if (!data)
@@ -99,11 +94,10 @@ glCompTex *glCompSetAddNewTexImage(glCompSet *s, int width, int height,
 
 glCompTex *glCompSetAddNewTexLabel(glCompSet *s, char *def, int fs, char *text,
                                    bool is2D) {
-    int Er, width, height;
+    int width, height;
     glCompTex *t;
     cairo_surface_t *surface = NULL;
     unsigned char *data = NULL;
-    Er = 0;
     if (!def)
 	return NULL;
     /*first check if the same label with same font def created before
@@ -111,9 +105,9 @@ glCompTex *glCompSetAddNewTexLabel(glCompSet *s, char *def, int fs, char *text,
      */
     for (size_t ind = 0; ind < s->textureCount; ind++) {
 	if (s->textures[ind]->type == glTexLabel) {
-	    if (strcmp(def, s->textures[ind]->def) == 0
+	    if (streq(def, s->textures[ind]->def)
 		&& s->textures[ind]->type == glTexLabel
-		&& strcmp(text, s->textures[ind]->text) == 0
+		&& streq(text, s->textures[ind]->text)
 		&& s->textures[ind]->fontSize==fs) {
 		s->textures[ind]->userCount++;
 		return s->textures[ind];
@@ -122,17 +116,13 @@ glCompTex *glCompSetAddNewTexLabel(glCompSet *s, char *def, int fs, char *text,
     }
 
 
-    data = glCompCreatePangoTexture(def, fs, text, surface, &width, &height);
+    data = glCompCreatePangoTexture(def, fs, text, &surface, &width, &height);
     if (!data)			/*pango error , */
 	return NULL;
     t = glCompSetAddNewTexture(s, width, height, data, is2D);
-    if (!t)
-	Er = 1;
     cairo_surface_destroy(surface);
-
-    if (Er) {
+    if (!t) {
 	free(data);
-	free(t);
 	return NULL;
     }
 
